
### Development Environment

Setup Requires [uv] . See [here](https://fpgmaas.github.io/cookiecutter-uv/getting-started/#set-up-your-development-environment) for more details.

Then, install the environment and the pre-commit hooks with

```bash
make install
```

Now in vs code you can run `Python: select interpreter` and chose the `.venv` folder in the repo root.
